Enum serial_io::ClearBuffer [−][src]
pub enum ClearBuffer {
Input,
Output,
All,
}Expand description
Specifies which buffer or buffers to purge when calling clear
Variants
Specify to clear data received but not read
Specify to clear data written but not yet transmitted
Specify to clear both data received and data not yet transmitted