Struct serial_io::TTYPort [−][src]
pub struct TTYPort { /* fields omitted */ }Expand description
A serial port implementation for POSIX TTY ports
The port will be closed when the value is dropped. However, this struct
should not be instantiated directly by using TTYPort::open(), instead use
the cross-platform serialport::open() or
serialport::open_with_settings().
Implementations
Opens a TTY device as a serial port.
path should be the path to a TTY device, e.g., /dev/ttyS0.
Ports are opened in exclusive mode by default. If this is undesireable
behavior, use TTYPort::set_exclusive(false).
Errors
NoDeviceif the device could not be opened. This could indicate that the device is already in use.InvalidInputifpathis not a valid device name.Iofor any other error while opening or initializing the device.
Returns the exclusivity of the port
If a port is exclusive, then trying to open the same device path again will fail.
Sets the exclusivity of the port
If a port is exclusive, then trying to open the same device path again will fail.
See the man pages for the tiocexcl and tiocnxcl ioctl’s for more details.
Errors
Iofor any error while setting exclusivity for the port.
Create a pair of pseudo serial terminals
Returns
Two connected TTYPort objects: (master, slave)
Errors
Attempting any IO or parameter settings on the slave tty after the master tty is closed will return errors.
On some platforms manipulating the master port will fail and only modifying the slave port is possible.
Examples
use serialport::TTYPort; let (master, slave) = TTYPort::pair().unwrap();
Sends 0-valued bits over the port for a set duration
Attempts to clone the SerialPort. This allow you to write and read simultaneously from the
same serial connection. Please note that if you want a real asynchronous serial port you
should look at mio-serial or
tokio-serial.
Also, you must be very careful when changing the settings of a cloned SerialPort : since
the settings are cached on a per object basis, trying to modify them from two different
objects can cause some nasty behavior.
This is the same as SerialPort::try_clone() but returns the concrete type instead.
Errors
This function returns an error if the serial port couldn’t be cloned.